import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/layout'
import store from '@/store'

Vue.use(VueRouter)

const routes = [
  {
    path: '/',
    component: Layout,
    children: [
      {
        path: '',
        name: 'Index',
        component: () => import('@/views/Home/HomeIndex.vue'),
        meta: {
          title: '首页'
        }
      },
      {
        path: 'policyadvice',
        name: 'PolicyAdvice',
        component: () => import('@/views/PolicyAdvice/PolicyAdviceIndex.vue'),
        meta: {
          title: '政策咨询'
        }
      },
      {
        path: 'recruitmentemployment',
        name: 'RecruitmentEmploymentIndex',
        component: () =>
          import(
            '@/views/RecruitmentEmployment/RecruitmentEmploymentIndex.vue'
          ),
        meta: {
          title: '招聘就业'
        }
      },
      {
        path: 'cooperativeenterprise',
        name: 'CooperativeEnterpriseIndex',
        component: () =>
          import(
            '@/views/CooperativeEnterprise/CooperativeEnterpriseIndex.vue'
          ),
        meta: {
          title: '合作企业'
        }
      },
      {
        path: 'enterprisedetails',
        name: 'EnterpriseDetailsIndex',
        component: () =>
          import(
            '@/views/CooperativeEnterprise/EnterpriseDetails/EnterpriseDetailsIndex.vue'
          ),
        meta: {
          title: '企业详情'
        }
      },
      {
        path: 'cooperativecolleges',
        name: 'CooperativeCollegesIndex',
        component: () =>
          import('@/views/CooperativeColleges/CooperativeCollegesIndex.vue'),
        meta: {
          title: '合作院校'
        }
      },
      {
        path: 'collegesdetails',
        name: 'CollegesDetailsIndex',
        component: () =>
          import(
            '@/views/CooperativeColleges/CollegesDetails/CollegesDetailsIndex.vue'
          ),
        meta: {
          title: '院校详情'
        }
      },
      {
        path: 'skilltraining',
        name: 'SkillTrainingIndex',
        component: () => import('@/views/SkillTraining/SkillTrainingIndex.vue'),
        meta: {
          title: '技能培训'
        }
      },
      {
        path: 'coursevideo',
        name: 'CourseVideoIndex',
        component: () => import('@/views/SkillTraining/CourseVideo/CourseVideoIndex.vue'),
        meta: {
          title: '课程详情'
        }
      },
      {
        path: 'workguide',
        name: 'WorkGuideIndex',
        component: () => import('@/views/WorkGuide/WorkGuideIndex.vue'),
        meta: {
          title: '创业指引'
        }
      },
      {
        path: 'educationpromote',
        name: 'EducationPromoteIndex',
        component: () =>
          import('@/views/EducationPromote/EducationPromoteIndex.vue'),
        meta: {
          title: '学历提升'
        }
      },
      {
        path: 'adaptivetraining',
        name: 'AdaptiveTrainingIndex',
        component: () =>
          import('@/views/AdaptiveTraining/AdaptiveTrainingIndex.vue'),
        meta: {
          title: '适应性培训'
        }
      },
      {
        path: 'personalcenter',
        name: 'PersonalCenterIndex',
        component: () =>
          import('@/views/PersonalCenter/PersonalCenterIndex.vue'),
        meta: {
          title: '我的'
        }
      },
      {
        path: 'setting',
        name: 'SettingIndex',
        component: () =>
          import('@/views/PersonalCenter/Setting/SettingIndex.vue'),
        meta: {
          title: '设置'
        }
      },
      {
        path: 'applyeducationauth',
        name: 'ApplyEducationAuthIndex',
        component: () =>
          import('@/views/PersonalCenter/ApplyEducationAuth/ApplyEducationAuthIndex.vue'),
        meta: {
          title: '退役军人认证'
        }
      },
      {
        path: 'newscenter',
        name: 'NewsCenterIndex',
        component: () =>
          import('@/views/NewsCenter/NewsCenterIndex.vue'),
        meta: {
          title: '新闻中心'
        }
      },
      {
        path: 'newsdetails',
        name: 'NewsDetailsIndex',
        component: () =>
          import('@/views/NewsCenter/NewsDetails/NewsDetailsIndex.vue'),
        meta: {
          title: '新闻详情'
        }
      },
      {
        path: 'noticedetails',
        name: 'NoticeDetailsIndex',
        component: () =>
          import('@/views/NewsCenter/NoticeDetails/NoticeDetailsIndex.vue'),
        meta: {
          title: '通知详情'
        }
      }
    ]
  },
  {
    path: '/login',
    name: 'Login',
    component: () => import('@/views/Login/LoginIndex.vue'),
    meta: {
      title: '登录'
    }
  }
]

const router = new VueRouter({
  mode: 'history',
  routes
})
router.beforeEach((to, from, next) => {
  /* 路由发生变化修改页面title */
  if (to.meta.title) {
    document.title = to.meta.title
  }
  if (store.state.user.token && !store.state.user.isLogin) {
    store.dispatch('GetUserInfo')
  }
  next()
})

export default router
